@@ -79,7 +79,8 @@ if ($nome_squadra == $giocatore or $nome_squadra == "tutti") {
 
 $dati_squadra = @file("squadra_$giocatore");
 $soprannome_squadra = $dati_squadra[3];
-$soprannome_squadra = ereg_replace("\n","",$soprannome_squadra);
+$soprannome_squadra = ereg_replace("
+","",$soprannome_squadra);
 echo "<center><font size=+1>";
 if ($soprannome_squadra) echo "<b>$soprannome_squadra</b>";
 else echo "Squadra";
