@@ -38,12 +38,15 @@ for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
 $numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
-$numero = ereg_replace("\n","",$numero);
+$numero = ereg_replace("
+","",$numero);
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
-$nome = ereg_replace("\n","",$nome);
+$nome = ereg_replace("
+","",$nome);
 $nome = ereg_replace("\"","",$nome);
 $ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
-$ruolo = ereg_replace("\n","",$ruolo);
+$ruolo = ereg_replace("
+","",$ruolo);
 if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
 if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
 if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
